/** A registered command in the command registry. */
export interface ICommandEntry {
    /** The command ID (conventionally, e.g., "myextension.mycommand"). */
    command: string;
    /** The function called to run the command and return an async value. */
    run: (...args: any[]) => Promise<any>;
}
export interface IExecuteCommandParams {
    /**
     * The identifier of the actual command handler.
     */
    command: string;
    /**
     * Arguments that the command should be invoked with.
     */
    arguments?: any[];
}
export interface ICommandRegistry {
    registerCommand: (a: {
        command: string;
        run: (...args: any[]) => any;
    }) => any;
    executeCommand: (a: {
        command: any;
        arguments?: any[];
    }) => any;
    deregisterCommand(entryToDeregister: ICommandEntry): boolean;
}
