import { Observable } from 'rxjs';
import { ISelection } from '@vscode-alt/monaco-editor/esm/vs/editor/common/core/selection';
import { IRange } from '@vscode-alt/monaco-editor/esm/vs/editor/common/core/range';
import * as modes from '@vscode-alt/monaco-editor/esm/vs/editor/common/modes';
import { ISingleEditOperation } from '@vscode-alt/monaco-editor/esm/vs/editor/common/model';
import { ITextDocumentIdentifier, ITextDocumentPositionParams } from '@workbench-stack/core';
import { WorkspaceSymbolDto, IRawColorInfo } from '../protocol';
export interface ITextDocumentParams {
    textDocument: ITextDocumentIdentifier;
}
export interface ITextDocumentLinkParams {
    link: modes.ILink;
}
export interface ITextDocumentColorInfoParams extends ITextDocumentParams {
    colorInfo: IRawColorInfo;
}
export interface ITextSignatureHelpParams extends ITextDocumentParams {
    context: modes.SignatureHelpContext;
}
export interface ICodeLensParams extends ITextDocumentParams {
    symbol: modes.CodeLens;
}
export interface ICodeActionsParams extends ITextDocumentPositionParams {
    rangeOrSelection: IRange | ISelection;
    context: modes.ReferenceContext;
}
export interface IWorkspaceSymbolsParams {
    symbol: WorkspaceSymbolDto;
}
export interface IDocumentFormattingEditsParams extends ITextDocumentParams {
    options: modes.FormattingOptions;
}
export interface IDocumentRangeFormattingEditsParams extends IDocumentFormattingEditsParams {
    range: IRange;
}
export interface IOnTypeFormattingEditsParams extends ITextDocumentParams {
    ch: string;
    options: modes.FormattingOptions;
}
export interface IReferencesParams extends ITextDocumentPositionParams {
    context: modes.ReferenceContext;
}
export interface ICompletionParams extends ITextDocumentPositionParams {
    context: modes.CompletionContext;
}
export interface IRenameParams extends ITextDocumentPositionParams {
    rename: string;
}
/**
 * Function signature for retrieving related locations given a location (e.g., definition, implementation, and type
 * definition).
 */
export type ProvideTextDocumentLocationSignature<P extends ITextDocumentPositionParams = ITextDocumentPositionParams, L extends modes.Location = modes.Location> = (params: P) => Observable<L | L[] | null>;
export type ProvideImplementationSignature = (params: ITextDocumentPositionParams) => Observable<modes.Definition | modes.LocationLink[]>;
export type ProvideDeclarationSignature = (params: ITextDocumentPositionParams) => Observable<modes.Definition | modes.LocationLink[]>;
export type ProvideDefinitionSignature = (params: ITextDocumentPositionParams) => Observable<modes.Definition | modes.LocationLink[]>;
export type ProvideSignatureHelpSignature = (params: ITextSignatureHelpParams) => Observable<modes.SignatureHelp | null | undefined>;
export type ProvideReferenceSignature = (params: IReferencesParams) => Observable<modes.Location[] | null | undefined>;
export type ProvideHoverSignature = (params: ITextDocumentPositionParams) => Observable<modes.Hover | null | undefined>;
export type ProvideCompletionItemSignature = (params: ITextDocumentPositionParams) => Observable<modes.CompletionList>;
export type ProvideDocumentSymbolSignature = (params: ITextDocumentPositionParams) => Observable<modes.DocumentSymbol[] | undefined>;
export type ProvideDocumentFormattingEditSignature = (params: IDocumentFormattingEditsParams) => Observable<ISingleEditOperation[] | undefined>;
export type ProvideDocumentRangeFormattingEditSignature = (params: IDocumentRangeFormattingEditsParams) => Observable<modes.TextEdit[] | undefined>;
export type ProvideDocumentHighlightSignature = (params: ITextDocumentPositionParams) => Observable<modes.DocumentHighlight[]>;
export type ProvideRenameSignature = (params: IRenameParams) => Observable<modes.RenameProvider>;
